You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kylin.apache.org by li...@apache.org on 2016/12/07 04:29:21 UTC

[04/50] [abbrv] kylin git commit: minor, fix typo

minor, fix typo


Project: http://git-wip-us.apache.org/repos/asf/kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/kylin/commit/c3d62e9c
Tree: http://git-wip-us.apache.org/repos/asf/kylin/tree/c3d62e9c
Diff: http://git-wip-us.apache.org/repos/asf/kylin/diff/c3d62e9c

Branch: refs/heads/master-hbase1.x
Commit: c3d62e9c5e6c39771bec1bbe2660130ff2033ef3
Parents: b1448e5
Author: lidongsjtu <li...@apache.org>
Authored: Mon Nov 28 23:48:46 2016 +0800
Committer: lidongsjtu <li...@apache.org>
Committed: Mon Nov 28 23:48:46 2016 +0800

----------------------------------------------------------------------
 build/smoke-test/testDiag.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/kylin/blob/c3d62e9c/build/smoke-test/testDiag.py
----------------------------------------------------------------------
diff --git a/build/smoke-test/testDiag.py b/build/smoke-test/testDiag.py
index cc932da..588864b 100644
--- a/build/smoke-test/testDiag.py
+++ b/build/smoke-test/testDiag.py
@@ -15,7 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
 # This is python unittest used in smoke-test.sh, aim to testing query via rest APIs.
 
 import unittest
 import requests
@@ -40,5 +40,5 @@ class testDiag(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    print 'Test Diagnogis for Kylin sample.'
+    print 'Test Diagnosis for Kylin sample.'
     unittest.main()
@@ -15,7 +15,7 @@
 # limitations under the License.
 #
-# This is python unittest used in smoke-test.sh, aim to testing query via rest APIs.
+# This is python unittest used in smoke-test.sh, aim to testing diagnosis via rest APIs.
 
 import unittest